@@ -1,5 +1,6 @@
 package Dezi::Indexer::Doc;
 use Moose;
+use MooseX::XSAccessor;
 with 'Dezi::Role';
 use Types::Standard qw( Str HashRef Int InstanceOf );
 use Dezi::Types qw( DeziUriStr DeziEpoch );
@@ -14,14 +15,15 @@ use Dezi::Indexer::Headers;
 
 use namespace::sweep;
 
-our $VERSION = '0.004';
+our $VERSION = '0.005';
+
+my $default_headers = Dezi::Indexer::Headers->new();
 
 my ( $locale, $lang, $charset );
 {
 
     # inside a block to reduce impact on any regex
     use POSIX;
-    use locale;
 
     $locale = setlocale(POSIX::LC_CTYPE);
     ( $lang, $charset ) = split( m/\./, $locale );
@@ -34,6 +36,7 @@ has 'modtime' => (
     isa     => DeziEpoch,
     coerce  => 1,
     default => sub { time() },
+    lazy    => 1,
 );
 has 'type'    => ( is => 'rw', isa => Str );
 has 'parser'  => ( is => 'rw', isa => Str );
@@ -46,7 +49,7 @@ has 'version' => ( is => 'rw', isa => Str, default => sub {3} );
 has 'headers' => (
     is       => 'rw',
     isa      => InstanceOf ['Dezi::Indexer::Headers'],
-    default  => sub { Dezi::Indexer::Headers->new() },
+    default  => sub {$default_headers},
     required => 1,
 );
 
@@ -62,7 +65,8 @@ Dezi::Indexer::Doc - Document object class for passing to Dezi::Indexer
   # and override filter() method
   
   package MyDoc;
-  use base qw( Dezi::Indexer::Doc );
+  use Moose;
+  extends 'Dezi::Indexer::Doc';
   
   sub filter {
     my $doc = shift;
@@ -129,7 +133,7 @@ A hashref.
 =item version
 
 Swish-e 2.x or Swish3 style headers. Value should be C<2> or C<3>.
-Default is C<2>.
+Default is C<3>.
 
 =back
 
@@ -153,7 +157,7 @@ being process()ed by the Indexer.
 
 The default is to do nothing.
 
-This method can also be set using the filter() callback in Dezi->new().
+This method can also be set using the filter() callback in Dezi::App->new().
 
 =cut
 
@@ -175,9 +179,11 @@ Example:
 sub as_string {
     my $self = shift;
 
+    my $body = $self->content;
+
     # we ignore size() and let Headers compute it based on actual content()
     return $self->headers->head(
-        $self->content,
+        $body,
         {   url     => $self->url,
             modtime => $self->modtime,
             type    => $self->type,
@@ -185,7 +191,7 @@ sub as_string {
             parser  => $self->parser,
             version => $self->version,
         }
-    ) . $self->content;
+    ) . $body;
 
 }
 
